@@ -317,6 +317,16 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Room#setPermissions',
+			'url' => '/api/{apiVersion}/room/{token}/permissions/{mode}',
+			'verb' => 'PUT',
+			'requirements' => [
+				'apiVersion' => 'v(4)',
+				'token' => '^[a-z0-9]{4,30}$',
+				'mode' => '^(call|default)$',
+			],
+		],
 		[
 			'name' => 'Room#getParticipants',
 			'url' => '/api/{apiVersion}/room/{token}/participants',
@@ -354,8 +364,17 @@ return [
 			],
 		],
 		[
-			'name' => 'Room#setAttendeePublishingPermissions',
-			'url' => '/api/{apiVersion}/room/{token}/attendees/publishing-permissions',
+			'name' => 'Room#setAttendeePermissions',
+			'url' => '/api/{apiVersion}/room/{token}/attendees/permissions',
+			'verb' => 'PUT',
+			'requirements' => [
+				'apiVersion' => 'v(4)',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
+		[
+			'name' => 'Room#setAllAttendeesPermissions',
+			'url' => '/api/{apiVersion}/room/{token}/attendees/permissions/all',
 			'verb' => 'PUT',
 			'requirements' => [
 				'apiVersion' => 'v(4)',
@@ -444,6 +463,15 @@ return [
 				'token' => '^[a-z0-9]{4,30}$',
 			],
 		],
+		[
+			'name' => 'Room#setNotificationCalls',
+			'url' => '/api/{apiVersion}/room/{token}/notify-calls',
+			'verb' => 'POST',
+			'requirements' => [
+				'apiVersion' => 'v(4)',
+				'token' => '^[a-z0-9]{4,30}$',
+			],
+		],
 		[
 			'name' => 'Room#setLobby',
 			'url' => '/api/{apiVersion}/room/{token}/webinar/lobby',
@@ -523,6 +551,27 @@ return [
 			],
 		],
 
+		/**
+		 * Federation
+		 */
+
+		[
+			'name' => 'Federation#acceptShare',
+			'url' => 'api/{apiVersion}/federation/invitation/{id}',
+			'verb' => 'POST',
+			'requirements' => [
+				'apiVersion' => 'v1',
+			],
+		],
+		[
+			'name' => 'Federation#rejectShare',
+			'url' => 'api/{apiVersion}/federation/invitation/{id}',
+			'verb' => 'DELETE',
+			'requirements' => [
+				'apiVersion' => 'v1',
+			],
+		],
+
 		/**
 		 * PublicShareAuth
 		 */
