@@ -89,16 +89,16 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "You can invite others in the participant tab of the sidebar",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "You can invite others in the participant tab of the sidebar or share this link to invite others!",
     "Share this link to invite others!" : "Share this link to invite others!",
+    "Dismiss" : "Dismiss",
     "Show your screen" : "Show your screen",
     "Stop screensharing" : "Stop screensharing",
-    "Settings" : "Settings",
-    "Dismiss" : "Dismiss",
     "No audio" : "No audio",
     "Mute audio" : "Mute audio",
     "Disable video" : "Disable video",
     "Enable video" : "Enable video",
     "Screensharing options" : "Screensharing options",
     "Enable screensharing" : "Enable screensharing",
+    "Grid view" : "Grid view",
     "Screensharing requires the page to be loaded through HTTPS." : "Screensharing requires the page to be loaded through HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Sharing your screen only works with Firefox version 52 or newer.",
     "Screensharing extension is required to share your screen." : "Screensharing extension is required to share your screen.",
@@ -141,10 +141,10 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participants",
     "Chat" : "Chat",
+    "Settings" : "Settings",
     "Keyboard shortcuts" : "Keyboard shortcuts",
     "Search" : "Search",
     "Rename conversation" : "Rename conversation",
-    "Grid view" : "Grid view",
     "Send" : "Send",
     "Start a conversation" : "Start a conversation",
     "Join a conversation or start a new one" : "Join a conversation or start a new one",
@@ -162,24 +162,13 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Talk on your mobile devices",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
-    "New in Talk 6" : "New in Talk 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- One-to-one conversations are now persistent and can not be turned into group conversations by accident any more. Also when one of the participants leaves the conversation, the conversation is not automatically deleted any more. Only if both participants leave, the conversation is deleted from the server",
-    "New in Talk 7" : "New in Talk 7",
-    "New in Talk 8" : "New in Talk 8",
-    "New in Talk 9" : "New in Talk 9",
-    "New in Talk 10" : "New in Talk 10",
-    "{user} wants to talk with you" : "{user} wants to talk with you",
-    "UDP and TCP" : "UDP and TCP",
-    "UDP only" : "UDP only",
-    "TCP only" : "TCP only",
     "Mute audio (m)" : "Mute audio (m)",
     "Unmute audio (m)" : "Unmute audio (m)",
     "Disable video (v)" : "Disable video (v)",
     "Enable video (v)" : "Enable video (v)",
     "Camera" : "Camera",
     "Remove" : "Remove",
-    "Enabled" : "Enabled",
-    "Share link" : "Share link",
     "Exit fullscreen (f)" : "Exit fullscreen (f)",
     "Fullscreen (f)" : "Fullscreen (f)"
 },
