@@ -262,8 +262,8 @@ OC.L10N.register(
     "Expired" : "Senvalidiĝis",
     "Saved" : "Konservita",
     "Copy link" : "Kopii ligilon",
-    "Settings" : "Agordoj",
     "Dismiss" : "Preterpasi",
+    "Grid view" : "Krada vido",
     "Back" : "Antaŭen",
     "You" : "Vi",
     "Favorite" : "Pliŝatata",
@@ -290,17 +290,15 @@ OC.L10N.register(
     "No results" : "Neniu rezulto",
     "Add users or groups" : "Add users or groups",
     "Chat" : "Babili",
+    "Settings" : "Agordoj",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Search" : "Serĉi",
-    "Grid view" : "Krada vido",
     "Send" : "Sendi",
     "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
     "Camera" : "Fotilo",
-    "Remove" : "Forigi",
-    "Enabled" : "Ŝaltita",
-    "Share link" : "Kunhavigi ligilon"
+    "Remove" : "Forigi"
 },
 "nplurals=2; plural=(n != 1);");
