@@ -29,12 +29,12 @@ OC.L10N.register(
     "TURN server protocols" : "Protocolos del servidor TURN",
     "Copy link" : "Copiar enlace",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
+    "Dismiss" : "Despedir",
     "Show your screen" : "Mostrar su pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Settings" : "Ajustes",
-    "Dismiss" : "Despedir",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
+    "Grid view" : "Vista de cuadrícula",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
@@ -71,10 +71,10 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
+    "Settings" : "Ajustes",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Search" : "Buscar",
     "Rename conversation" : "Renombrar conversación",
-    "Grid view" : "Vista de cuadrícula",
     "Send" : "Enviar",
     "Start a conversation" : "Iniciar una conversación",
     "Default" : "Predeterminado",
@@ -88,12 +88,7 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "sólo UDP",
-    "TCP only" : "sólo TCP",
     "Camera" : "Cámara",
-    "Remove" : "Borrar",
-    "Enabled" : "Habilitado",
-    "Share link" : "Compartir link"
+    "Remove" : "Borrar"
 },
 "nplurals=2; plural=(n != 1);");
