@@ -126,16 +126,16 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Dismiss" : "Descartar",
     "Show your screen" : "Mostrar tu pantalla",
     "Stop screensharing" : "Dejar de compartir la pantalla",
-    "Settings" : "Configuraciones ",
-    "Dismiss" : "Descartar",
     "No audio" : "Sin audio",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
+    "Grid view" : "Vista de cuadrícula",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
@@ -177,10 +177,10 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
+    "Settings" : "Configuraciones ",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
     "Rename conversation" : "Renombrar conversación",
-    "Grid view" : "Vista de cuadrícula",
     "Send" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
     "Default" : "Predeterminado",
@@ -198,18 +198,11 @@ OC.L10N.register(
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Coversaciones uno-a-uno ahora son persistentes y ya no pueden ser convertidas en conversaciones de grupo por accidente. Además cuando uno de los participantes abandona la conversación, la conversación ya no es eliminada automáticamente. Solo si ambos participantes abandonan la conversación, la conversación es eliminada del servidor.",
-    "New in Talk 7" : "Nuevo en Talk 7",
-    "{user} wants to talk with you" : "{user} quiere hablar contigo",
-    "UDP and TCP" : "UDP y TCP",
-    "UDP only" : "UDP únicamente",
-    "TCP only" : "TCP únicamente",
     "Mute audio (m)" : "Silenciar audio (m)",
     "Unmute audio (m)" : "Habilitar audio (m)",
     "Disable video (v)" : "Deshabilitar video (v)",
     "Enable video (v)" : "Habilitar video (v)",
     "Remove" : "Eliminar",
-    "Enabled" : "Habilitado",
-    "Share link" : "Compartir liga",
     "Exit fullscreen (f)" : "Salir de pantalla completa (f)",
     "Fullscreen (f)" : "Pantalla completa (f)"
 },
