@@ -87,6 +87,7 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} شما را به یک گفتگو گروهی دعوت کرد: {call}",
     "Open settings" : "تنظیمات را باز کنید",
     "Messages" : "پیام ها",
+    "There is no such account registered." : "این حساب کاربری ثبت نام نشده است.",
     "United Arab Emirates" : "امارات متحده عربی",
     "Afghanistan" : "افغانستان",
     "Albania" : "آلبانی",
@@ -263,8 +264,8 @@ OC.L10N.register(
     "Copy link" : "کپی کردن لینک",
     "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
     "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
-    "Settings" : "تنظیمات",
     "Dismiss" : "پنهان کن",
+    "Grid view" : "نمایش گرید",
     "Back" : "بازگشت",
     "You" : "شما",
     "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
@@ -290,7 +291,6 @@ OC.L10N.register(
     "Add participants" : "افزودن عضو",
     "Close" : "بستن",
     "Conversation name" : "نام مکالمه",
-    "Camera" : "دوربین",
     "Reply" : "پاسخ",
     "Today" : "Today",
     "Yesterday" : "دیروز",
@@ -303,10 +303,10 @@ OC.L10N.register(
     "No results" : "نتیجه ای یافت نشد",
     "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
     "Participants" : "شركت كنندگان",
+    "Settings" : "تنظیمات",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
     "Search" : "جستجو کردن",
     "Rename conversation" : "تغییر نام مکالمه",
-    "Grid view" : "نمایش گرید",
     "Send" : "ارسال",
     "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
     "Start a conversation" : "مکالمه را شروع کنید",
@@ -316,14 +316,10 @@ OC.L10N.register(
     "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
     "Android app" : "اپ اندروید",
     "iOS app" : "اپ iOS",
-    "New in Talk 6" : "جدید در Talk 6",
     "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- مکالمات یک به یک هم اکنون برقرار است و دیگر نمی توان به طور تصادفی به مکالمه های گروهی تبدیل کرد. همچنین وقتی یکی از شرکت کنندگان مکالمه را ترک می کند ، مکالمه دیگر به طور خودکار حذف نمی شود. فقط در صورت ترک هر دو شرکت کننده ، مکالمه از سرور حذف می شود",
-    "New in Talk 7" : "جدید در Talk 7",
     "Allow guests to join via link " : "مجاز بودن عضویت مهمان‌ها با پیوند",
+    "Camera" : "دوربین",
     "Remove" : "حذف",
-    "Enabled" : "فعال شده",
-    "Add participants to the conversation" : "افزودن عضو به گفتگو",
-    "Share link" : "لینک را به اشتراک بگذارید",
     "Fullscreen (f)" : "تمام صفحه (f)"
 },
 "nplurals=2; plural=(n > 1);");
