@@ -46,15 +46,15 @@ OC.L10N.register(
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
+    "Dismiss" : "დათხოვნა",
     "Show your screen" : "თქვენი ეკრანის ჩვენება",
     "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
-    "Settings" : "პარამეტრები",
-    "Dismiss" : "დათხოვნა",
     "Mute audio" : "ხმის ჩახშობა",
     "Disable video" : "ვიდეოს გათიშვა",
     "Enable video" : "ვიდეოს ამოქმედება",
     "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
     "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
+    "Grid view" : "ბადისებური ხედი",
     "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
     "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
     "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
@@ -93,9 +93,9 @@ OC.L10N.register(
     "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
     "Participants" : "მონაწილეები",
     "Chat" : "ჩეთი",
+    "Settings" : "პარამეტრები",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Search" : "ძიება",
-    "Grid view" : "ბადისებური ხედი",
     "Send" : "გაგზავნა",
     "Default" : "საწყისი",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
@@ -109,12 +109,6 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
     "Android app" : "Android აპლიკაცია",
     "iOS app" : "iOS აპლიკაცია",
-    "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
-    "UDP and TCP" : "UDP და TCP",
-    "UDP only" : "მხოლოდ UDP",
-    "TCP only" : "მხოლოდ TCP",
-    "Remove" : "წაშლა",
-    "Enabled" : "მოქმედია",
-    "Share link" : "ბმულის გაზიარება"
+    "Remove" : "წაშლა"
 },
 "nplurals=2; plural=(n!=1);");
