@@ -81,13 +81,13 @@ OC.L10N.register(
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
-    "Settings" : "Definições",
     "Dismiss" : "Dispensar",
     "Mute audio" : "Silenciar áudio",
     "Disable video" : "desactivar vídeo",
     "Enable video" : "activar vídeo",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Activar partilha de ecrã",
+    "Grid view" : "Vista em grelha",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
     "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
@@ -130,10 +130,10 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participantes",
     "Chat" : "Conversa",
+    "Settings" : "Definições",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
     "Rename conversation" : "Renomear conversação",
-    "Grid view" : "Vista em grelha",
     "Send" : "Enviar",
     "Start a conversation" : "Iniciar uma conversação",
     "Default" : "Predefinida",
@@ -145,14 +145,7 @@ OC.L10N.register(
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
-    "New in Talk 6" : "Novo em Talk 6",
-    "{user} wants to talk with you" : "{user} quer falar consigo",
-    "UDP and TCP" : "UDP e TCP",
-    "UDP only" : "Só UDP",
-    "TCP only" : "Só TCP",
     "Camera" : "Câmera",
-    "Remove" : "Remover",
-    "Enabled" : "Habilidado",
-    "Share link" : "Partilhar hiperligação"
+    "Remove" : "Remover"
 },
 "nplurals=2; plural=(n != 1);");
