@@ -166,12 +166,12 @@ OC.L10N.register(
     "TURN server protocols" : "Protokollet e serverit TURN",
     "Copy link" : "Kopjo linkun",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
+    "Dismiss" : "Hiq",
     "Show your screen" : "Shfaq ekranin tënd",
     "Stop screensharing" : "Ndalo ndarjen e ekranit",
-    "Settings" : "Rregullimet",
-    "Dismiss" : "Hiq",
     "Mute audio" : "Mute audio",
     "Disable video" : "Çaktivizo video",
+    "Grid view" : "Pamje galeri",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
     "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
@@ -206,10 +206,10 @@ OC.L10N.register(
     "guest" : "vizitor",
     "No results" : "Asnjë rezultat",
     "Add users or groups" : "Add users or groups",
+    "Settings" : "Rregullimet",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
     "Rename conversation" : "Riemërtojeni bisedën",
-    "Grid view" : "Pamje galeri",
     "Send" : "Dërgo",
     "Start a conversation" : "Filloni një bisedë",
     "Default" : "E paracaktuar",
@@ -223,12 +223,7 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
     "Android app" : "Aplikacion Android",
     "iOS app" : "Aplikacion iOS",
-    "UDP and TCP" : "UDP dhe TCP",
-    "UDP only" : "Vetëm UDP",
-    "TCP only" : "Vetëm TCP",
     "Camera" : "Kamera",
-    "Remove" : "Hiq",
-    "Enabled" : "I aktivizuar",
-    "Share link" : "Shpërndaj ndërlidhjen"
+    "Remove" : "Hiq"
 },
 "nplurals=2; plural=(n != 1);");
