@@ -68,10 +68,9 @@ OC.L10N.register(
     "Copy link" : "Скопіювати посилання",
     "Waiting for others to join the call …" : "Чекаємо, доки хтось приєднається до виклику...",
     "Share this link to invite others!" : "Поділіться цим посиланням з тими, кого бажаєте запросити!",
+    "Dismiss" : "Припинити",
     "Show your screen" : "Демонстрація екрану",
     "Stop screensharing" : "Припинити демонстрацію екрану",
-    "Settings" : "Налаштування",
-    "Dismiss" : "Припинити",
     "No audio" : "Вимкнути мікрофон",
     "Mute audio" : "Вимкнути мікрофон (m)",
     "Unmute audio" : "Увімкнути мікрофон",
@@ -80,6 +79,7 @@ OC.L10N.register(
     "Enable video" : "Увімкнути відео",
     "Screensharing options" : "Параметри демонстрації екрану",
     "Enable screensharing" : "Увімкнути демонстрацію екрану",
+    "Grid view" : "Упорядкування у формі сітки",
     "Screen sharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
     "Screensharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
     "Back" : "Назад",
@@ -136,12 +136,12 @@ OC.L10N.register(
     "Add users or circles" : "Додати користувачів або кола",
     "Participants" : "Учасники",
     "Chat" : "Чат",
+    "Settings" : "Налаштування",
     "Keyboard shortcuts" : "Гарячі клавіші",
     "Search" : "Пошук",
     "Start call" : "Почати виклик",
     "Toggle fullscreen" : "Перемкнути на весь екран",
     "Rename conversation" : "Перейменувати розмову",
-    "Grid view" : "Упорядкування у формі сітки",
     "Send" : "Надіслати",
     "Say hi to your friends and colleagues!" : "Привітайтеся з вашими друзями та колегами!",
     "Join a conversation or start a new one!" : "Приєднайтеся до розмови або почніть нову!",
@@ -161,9 +161,6 @@ OC.L10N.register(
     "Allow guests to join via link " : "Дозволити гостям приєднуватися через посилання",
     "Camera" : "Камера",
     "Remove" : "Вилучити",
-    "Enabled" : "Увімкнено",
-    "Add participants to the conversation" : "Додати учасників до розмови",
-    "Share link" : "Поширити посилання",
     "Exit fullscreen (f)" : "Вийти з повного екрану (f)",
     "Fullscreen (f)" : "На весь екран (f)"
 },
