@@ -271,10 +271,10 @@ OC.L10N.register(
     "Saved" : "儲存",
     "Copy link" : "複製連結",
     "Waiting for others to join the call …" : "等待其他人加入通話...",
-    "Settings" : "設定",
     "Dismiss" : "取消",
     "Mute audio" : "靜音",
     "Disable video" : "停用視訊",
+    "Grid view" : "網格檢視",
     "Back" : "返回",
     "You" : "您",
     "Favorite" : "我的最愛",
@@ -298,7 +298,6 @@ OC.L10N.register(
     "Password protect" : "密碼防護",
     "Close" : "關閉",
     "Conversation name" : "對話名稱",
-    "Camera" : "相機",
     "Reply" : "回覆",
     "Today" : "今天",
     "Yesterday" : "昨天",
@@ -312,11 +311,11 @@ OC.L10N.register(
     "Add users or groups" : "增加使用者或者群組",
     "Participants" : "參與者",
     "Chat" : "聊天",
+    "Settings" : "設定",
     "Keyboard shortcuts" : "快速鍵",
     "Search" : "搜尋",
     "Start call" : "通話",
     "Rename conversation" : "重新命名對話",
-    "Grid view" : "網格檢視",
     "Send" : "傳送",
     "Say hi to your friends and colleagues!" : "跟大家打招呼",
     "Start a conversation" : "新對話",
@@ -325,14 +324,10 @@ OC.L10N.register(
     "The password is wrong. Try again." : "密碼錯誤，請重試",
     "Android app" : "安卓應用",
     "iOS app" : "蘋果應用",
-    "UDP and TCP" : "UDP 和 TCP",
-    "UDP only" : "僅UDP",
-    "TCP only" : "僅TCP",
     "Mute audio (m)" : "靜音 (m)",
     "Allow guests to join via link " : "允許訪客透過連結加入",
+    "Camera" : "相機",
     "Remove" : "移除",
-    "Enabled" : "已啟用",
-    "Share link" : "分享連結",
     "Exit fullscreen (f)" : "離開全螢幕 (f)",
     "Fullscreen (f)" : "全螢幕 (f)"
 },
