@@ -27,6 +27,7 @@ use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Events\AddParticipantsEvent;
 use OCA\Talk\Events\AttendeesAddedEvent;
 use OCA\Talk\Events\AttendeesRemovedEvent;
+use OCA\Talk\Events\ModifyEveryoneEvent;
 use OCA\Talk\Events\ModifyLobbyEvent;
 use OCA\Talk\Events\ModifyParticipantEvent;
 use OCA\Talk\Events\ModifyRoomEvent;
@@ -46,6 +47,7 @@ use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\EventDispatcher\IEventListener;
 use OCP\IRequest;
+use OCP\ISession;
 use OCP\IUser;
 use OCP\IUserSession;
 use OCP\Share\IShare;
@@ -59,6 +61,8 @@ class Listener implements IEventListener {
 	protected $chatManager;
 	/** @var TalkSession */
 	protected $talkSession;
+	/** @var ISession */
+	protected $session;
 	/** @var IUserSession */
 	protected $userSession;
 	/** @var ITimeFactory */
@@ -67,11 +71,13 @@ class Listener implements IEventListener {
 	public function __construct(IRequest $request,
 								ChatManager $chatManager,
 								TalkSession $talkSession,
+								ISession $session,
 								IUserSession $userSession,
 								ITimeFactory $timeFactory) {
 		$this->request = $request;
 		$this->chatManager = $chatManager;
 		$this->talkSession = $talkSession;
+		$this->session = $session;
 		$this->userSession = $userSession;
 		$this->timeFactory = $timeFactory;
 	}
@@ -91,6 +97,15 @@ class Listener implements IEventListener {
 			}
 		});
 		$dispatcher->addListener(Room::EVENT_AFTER_SESSION_LEAVE_CALL, static function (ModifyParticipantEvent $event) {
+			if ($event instanceof ModifyEveryoneEvent) {
+				// No individual system message if the call is ended for everyone
+				return;
+			}
+
+			if ($event->getNewValue() === $event->getOldValue()) {
+				return;
+			}
+
 			$room = $event->getRoom();
 
 			$session = $event->getParticipant()->getSession();
@@ -154,15 +169,15 @@ class Listener implements IEventListener {
 		$dispatcher->addListener(Room::EVENT_AFTER_TYPE_SET, static function (ModifyRoomEvent $event) {
 			$room = $event->getRoom();
 
-			if ($event->getOldValue() === Room::ONE_TO_ONE_CALL) {
+			if ($event->getOldValue() === Room::TYPE_ONE_TO_ONE) {
 				return;
 			}
 
-			if ($event->getNewValue() === Room::PUBLIC_CALL) {
+			if ($event->getNewValue() === Room::TYPE_PUBLIC) {
 				/** @var self $listener */
 				$listener = \OC::$server->query(self::class);
 				$listener->sendSystemMessage($room, 'guests_allowed');
-			} elseif ($event->getNewValue() === Room::GROUP_CALL) {
+			} elseif ($event->getNewValue() === Room::TYPE_GROUP) {
 				/** @var self $listener */
 				$listener = \OC::$server->query(self::class);
 				$listener->sendSystemMessage($room, 'guests_disallowed');
@@ -171,7 +186,7 @@ class Listener implements IEventListener {
 		$dispatcher->addListener(Room::EVENT_AFTER_READONLY_SET, static function (ModifyRoomEvent $event) {
 			$room = $event->getRoom();
 
-			if ($room->getType() === Room::CHANGELOG_CONVERSATION) {
+			if ($room->getType() === Room::TYPE_CHANGELOG) {
 				return;
 			}
 
@@ -219,7 +234,7 @@ class Listener implements IEventListener {
 
 		$dispatcher->addListener(Room::EVENT_AFTER_USERS_ADD, static function (AddParticipantsEvent $event) {
 			$room = $event->getRoom();
-			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 				return;
 			}
 
@@ -255,7 +270,7 @@ class Listener implements IEventListener {
 		$dispatcher->addListener(Room::EVENT_AFTER_USER_REMOVE, static function (RemoveUserEvent $event) {
 			$room = $event->getRoom();
 
-			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 				return;
 			}
 
@@ -301,7 +316,7 @@ class Listener implements IEventListener {
 				$listener->sendSystemMessage($room, 'guest_moderator_demoted', ['session' => $attendee->getActorId()]);
 			}
 		});
-		$listener = function (GenericEvent $event) {
+		$listener = function (GenericEvent $event): void {
 			/** @var IShare $share */
 			$share = $event->getSubject();
 
@@ -348,6 +363,8 @@ class Listener implements IEventListener {
 		foreach ($event->getAttendees() as $attendee) {
 			if ($attendee->getActorType() === Attendee::ACTOR_GROUPS) {
 				$this->sendSystemMessage($event->getRoom(), 'group_added', ['group' => $attendee->getActorId()]);
+			} elseif ($attendee->getActorType() === Attendee::ACTOR_CIRCLES) {
+				$this->sendSystemMessage($event->getRoom(), 'circle_added', ['circle' => $attendee->getActorId()]);
 			}
 		}
 	}
@@ -356,6 +373,8 @@ class Listener implements IEventListener {
 		foreach ($event->getAttendees() as $attendee) {
 			if ($attendee->getActorType() === Attendee::ACTOR_GROUPS) {
 				$this->sendSystemMessage($event->getRoom(), 'group_removed', ['group' => $attendee->getActorId()]);
+			} elseif ($attendee->getActorType() === Attendee::ACTOR_CIRCLES) {
+				$this->sendSystemMessage($event->getRoom(), 'circle_removed', ['circle' => $attendee->getActorId()]);
 			}
 		}
 	}
@@ -367,11 +386,14 @@ class Listener implements IEventListener {
 		} else {
 			$user = $this->userSession->getUser();
 			if ($user instanceof IUser) {
-				$actorType = 'users';
+				$actorType = Attendee::ACTOR_USERS;
 				$actorId = $user->getUID();
-			} elseif (\OC::$CLI) {
+			} elseif (\OC::$CLI || $this->session->exists('talk-overwrite-actor-cli')) {
 				$actorType = Attendee::ACTOR_GUESTS;
 				$actorId = 'cli';
+			} elseif ($this->session->exists('talk-overwrite-actor')) {
+				$actorType = Attendee::ACTOR_USERS;
+				$actorId = $this->session->get('talk-overwrite-actor');
 			} else {
 				$actorType = Attendee::ACTOR_GUESTS;
 				$sessionId = $this->talkSession->getSessionForRoom($room->getToken());
@@ -394,7 +416,7 @@ class Listener implements IEventListener {
 		);
 	}
 
-	protected function getUserId() {
+	protected function getUserId(): ?string {
 		$user = $this->userSession->getUser();
 		return $user instanceof IUser ? $user->getUID() : null;
 	}
