@@ -52,6 +52,7 @@ use OCP\IRequest;
 use OCP\IUserManager;
 use OCP\RichObjectStrings\InvalidObjectExeption;
 use OCP\RichObjectStrings\IValidator;
+use OCP\Security\ITrustedDomainHelper;
 use OCP\User\Events\UserLiveStatusEvent;
 use OCP\UserStatus\IManager as IUserStatusManager;
 use OCP\UserStatus\IUserStatus;
@@ -109,6 +110,9 @@ class ChatController extends AEnvironmentAwareController {
 	/** @var IValidator */
 	protected $richObjectValidator;
 
+	/** @var ITrustedDomainHelper */
+	protected $trustedDomainHelper;
+
 	/** @var IL10N */
 	private $l;
 
@@ -130,6 +134,7 @@ class ChatController extends AEnvironmentAwareController {
 								ITimeFactory $timeFactory,
 								IEventDispatcher $eventDispatcher,
 								IValidator $richObjectValidator,
+								ITrustedDomainHelper $trustedDomainHelper,
 								IL10N $l) {
 		parent::__construct($appName, $request);
 
@@ -149,6 +154,7 @@ class ChatController extends AEnvironmentAwareController {
 		$this->timeFactory = $timeFactory;
 		$this->eventDispatcher = $eventDispatcher;
 		$this->richObjectValidator = $richObjectValidator;
+		$this->trustedDomainHelper = $trustedDomainHelper;
 		$this->l = $l;
 	}
 
@@ -160,6 +166,9 @@ class ChatController extends AEnvironmentAwareController {
 			if ($actorDisplayName) {
 				$this->guestManager->updateName($this->room, $this->participant, $actorDisplayName);
 			}
+		} elseif ($this->userId === MatterbridgeManager::BRIDGE_BOT_USERID && $actorDisplayName) {
+			$actorType = Attendee::ACTOR_BRIDGED;
+			$actorId = str_replace(["/", "\""], "", $actorDisplayName);
 		} else {
 			$actorType = Attendee::ACTOR_USERS;
 			$actorId = $this->userId;
@@ -282,6 +291,10 @@ class ChatController extends AEnvironmentAwareController {
 		$data['type'] = $objectType;
 		$data['id'] = $objectId;
 
+		if (isset($data['link']) && !$this->trustedDomainHelper->isTrustedUrl($data['link'])) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
 		try {
 			$this->richObjectValidator->validate('{object}', ['object' => $data]);
 		} catch (InvalidObjectExeption $e) {
@@ -558,9 +571,12 @@ class ChatController extends AEnvironmentAwareController {
 		$attendee = $this->participant->getAttendee();
 		$isOwnMessage = $message->getActorType() === $attendee->getActorType()
 			&& $message->getActorId() === $attendee->getActorId();
+
+		// Special case for if the message is a bridged message, then the message is the bridge bot's message.
+		$isOwnMessage = $isOwnMessage || ($message->getActorType() === Attendee::ACTOR_BRIDGED && $attendee->getActorId() === MatterbridgeManager::BRIDGE_BOT_USERID);
 		if (!$isOwnMessage
 			&& (!$this->participant->hasModeratorPermissions(false)
-				|| $this->room->getType() === Room::ONE_TO_ONE_CALL)) {
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE)) {
 			// Actor is not a moderator or not the owner of the message
 			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
@@ -614,7 +630,7 @@ class ChatController extends AEnvironmentAwareController {
 	public function clearHistory(): DataResponse {
 		$attendee = $this->participant->getAttendee();
 		if (!$this->participant->hasModeratorPermissions(false)
-				|| $this->room->getType() === Room::ONE_TO_ONE_CALL) {
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE) {
 			// Actor is not a moderator or not the owner of the message
 			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
@@ -700,26 +716,7 @@ class ChatController extends AEnvironmentAwareController {
 
 		$results = $this->prepareResultArray($results, $statuses);
 
-		$attendee = $this->participant->getAttendee();
-		$userId = $attendee->getActorType() === Attendee::ACTOR_USERS ? $attendee->getActorId() : '';
-		$roomDisplayName = $this->room->getDisplayName($userId);
-		if (($search === '' || strpos('all', $search) !== false || stripos($roomDisplayName, $search) !== false) && $this->room->getType() !== Room::ONE_TO_ONE_CALL) {
-			if ($search === '' ||
-				stripos($roomDisplayName, $search) === 0 ||
-				strpos('all', $search) === 0) {
-				array_unshift($results, [
-					'id' => 'all',
-					'label' => $roomDisplayName,
-					'source' => 'calls',
-				]);
-			} else {
-				$results[] = [
-					'id' => 'all',
-					'label' => $roomDisplayName,
-					'source' => 'calls',
-				];
-			}
-		}
+		$results = $this->chatManager->addConversationNotify($results, $search, $this->room, $this->participant);
 
 		return new DataResponse($results);
 	}
