@@ -205,7 +205,7 @@ class PageController extends Controller {
 				}
 
 				// If the room is not a public room, check if the user is in the participants
-				if ($room->getType() !== Room::PUBLIC_CALL) {
+				if ($room->getType() !== Room::TYPE_PUBLIC) {
 					$this->manager->getRoomForUser($room->getId(), $this->userId);
 				}
 			} catch (RoomNotFoundException $e) {
@@ -216,7 +216,7 @@ class PageController extends Controller {
 			if ($room instanceof Room && $room->hasPassword()) {
 				// If the user joined themselves or is not found, they need the password.
 				try {
-					$participant = $room->getParticipant($this->userId);
+					$participant = $room->getParticipant($this->userId, false);
 					$requirePassword = $participant->getAttendee()->getParticipantType() === Participant::USER_SELF_JOINED;
 				} catch (ParticipantNotFoundException $e) {
 					$requirePassword = true;
@@ -243,7 +243,7 @@ class PageController extends Controller {
 				}
 			}
 		} else {
-			$response = $this->api->createRoom(Room::ONE_TO_ONE_CALL, $callUser);
+			$response = $this->api->createRoom(Room::TYPE_ONE_TO_ONE, $callUser);
 			if ($response->getStatus() === Http::STATUS_OK
 				|| $response->getStatus() === Http::STATUS_CREATED) {
 				$data = $response->getData();
@@ -262,6 +262,15 @@ class PageController extends Controller {
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedConnectDomain('*');
 		$csp->addAllowedMediaDomain('blob:');
+		$csp->addAllowedWorkerSrcDomain('blob:');
+		$csp->addAllowedWorkerSrcDomain("'self'");
+		$csp->addAllowedChildSrcDomain('blob:');
+		$csp->addAllowedChildSrcDomain("'self'");
+		$csp->addAllowedScriptDomain('blob:');
+		$csp->addAllowedScriptDomain("'self'");
+		$csp->addAllowedConnectDomain('blob:');
+		$csp->addAllowedConnectDomain("'self'");
+		$csp->addAllowedImageDomain('https://*.tile.openstreetmap.org');
 		$response->setContentSecurityPolicy($csp);
 		return $response;
 	}
@@ -275,7 +284,7 @@ class PageController extends Controller {
 	protected function guestEnterRoom(string $token, string $password): Response {
 		try {
 			$room = $this->manager->getRoomByToken($token);
-			if ($room->getType() !== Room::PUBLIC_CALL) {
+			if ($room->getType() !== Room::TYPE_PUBLIC) {
 				throw new RoomNotFoundException();
 			}
 		} catch (RoomNotFoundException $e) {
@@ -314,6 +323,15 @@ class PageController extends Controller {
 		$csp = new ContentSecurityPolicy();
 		$csp->addAllowedConnectDomain('*');
 		$csp->addAllowedMediaDomain('blob:');
+		$csp->addAllowedWorkerSrcDomain('blob:');
+		$csp->addAllowedWorkerSrcDomain("'self'");
+		$csp->addAllowedChildSrcDomain('blob:');
+		$csp->addAllowedChildSrcDomain("'self'");
+		$csp->addAllowedScriptDomain('blob:');
+		$csp->addAllowedScriptDomain("'self'");
+		$csp->addAllowedConnectDomain('blob:');
+		$csp->addAllowedConnectDomain("'self'");
+		$csp->addAllowedImageDomain('https://*.tile.openstreetmap.org');
 		$response->setContentSecurityPolicy($csp);
 		return $response;
 	}
@@ -330,7 +348,7 @@ class PageController extends Controller {
 		if ($this->userId === null) {
 			try {
 				$room = $this->manager->getRoomByToken($token);
-				if ($room->getType() !== Room::PUBLIC_CALL) {
+				if ($room->getType() !== Room::TYPE_PUBLIC) {
 					throw new RoomNotFoundException();
 				}
 				return new RedirectResponse($this->url->linkToRoute('spreed.Page.showCall', ['token' => $token]));
