@@ -23,6 +23,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Events;
 
+use OCA\Talk\Participant;
 use OCA\Talk\Room;
 
 class ModifyRoomEvent extends RoomEvent {
@@ -33,21 +34,22 @@ class ModifyRoomEvent extends RoomEvent {
 	protected $newValue;
 	/** @var int|string|bool|null */
 	protected $oldValue;
+	/** @var Participant|null */
+	protected $actor;
 
 
 	public function __construct(Room $room,
 								string $parameter,
 								$newValue,
-								$oldValue = null) {
+								$oldValue = null,
+								?Participant $actor = null) {
 		parent::__construct($room);
 		$this->parameter = $parameter;
 		$this->newValue = $newValue;
 		$this->oldValue = $oldValue;
+		$this->actor = $actor;
 	}
 
-	/**
-	 * @return string
-	 */
 	public function getParameter(): string {
 		return $this->parameter;
 	}
@@ -65,4 +67,8 @@ class ModifyRoomEvent extends RoomEvent {
 	public function getOldValue() {
 		return $this->oldValue;
 	}
+
+	public function getActor(): ?Participant {
+		return $this->actor;
+	}
 }
