@@ -23,6 +23,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Events;
 
+use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 
@@ -31,14 +32,26 @@ class RemoveParticipantEvent extends ParticipantEvent {
 	/** @var string */
 	protected $reason;
 
+	/** @var Session[] */
+	protected $sessions;
+
 	public function __construct(Room $room,
 								Participant $participant,
-								string $reason) {
+								string $reason,
+								array $sessions = []) {
 		parent::__construct($room, $participant);
 		$this->reason = $reason;
+		$this->sessions = $sessions;
 	}
 
 	public function getReason(): string {
 		return $this->reason;
 	}
+
+	/**
+	 * @return Session[]
+	 */
+	public function getSessions(): array {
+		return $this->sessions;
+	}
 }
