@@ -32,12 +32,12 @@ class RemoveUserEvent extends RemoveParticipantEvent {
 	/** @var IUser */
 	protected $user;
 
-
 	public function __construct(Room $room,
 								Participant $participant,
 								IUser $user,
-								string $reason) {
-		parent::__construct($room, $participant, $reason);
+								string $reason,
+								array $sessions = []) {
+		parent::__construct($room, $participant, $reason, $sessions);
 		$this->user = $user;
 	}
 
