@@ -36,18 +36,21 @@ class Version10000Date20201012144235 extends SimpleMigrationStep {
 	 * @param IOutput $output
 	 * @param Closure $schemaClosure The `\Closure` returns a `ISchemaWrapper`
 	 * @param array $options
-	 * @return null|ISchemaWrapper
+	 *
+	 * @return ISchemaWrapper
 	 */
 	public function changeSchema(IOutput $output, Closure $schemaClosure, array $options): ISchemaWrapper {
 		/** @var ISchemaWrapper $schema */
 		$schema = $schemaClosure();
 
 		$table = $schema->getTable('talk_rooms');
-		$table->addColumn('sip_enabled', Types::SMALLINT, [
-			'notnull' => true,
-			'default' => 0,
-			'unsigned' => true,
-		]);
+		if (!$table->hasColumn('sip_enabled')) {
+			$table->addColumn('sip_enabled', Types::SMALLINT, [
+				'notnull' => true,
+				'default' => 0,
+				'unsigned' => true,
+			]);
+		}
 
 		return $schema;
 	}
