@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 /**
  * @copyright Copyright (c) 2017 Joas Schilling <coding@schilljs.com>
@@ -60,7 +61,6 @@ class Version2000Date20171026140257 extends SimpleMigrationStep {
 	 * @since 13.0.0
 	 */
 	public function postSchemaChange(IOutput $output, \Closure $schemaClosure, array $options): void {
-
 		if (version_compare($this->config->getAppValue('spreed', 'installed_version', '0.0.0'), '2.0.0', '<')) {
 			// Migrations only work after 2.0.0
 			return;
@@ -79,7 +79,7 @@ class Version2000Date20171026140257 extends SimpleMigrationStep {
 			->from('spreedme_rooms')
 			->where($query->expr()->emptyString('token'))
 			->orWhere($query->expr()->isNull('token'));
-		$result = $query->execute();
+		$result = $query->executeQuery();
 
 		$output->startProgress();
 		while ($row = $result->fetch()) {
@@ -89,10 +89,9 @@ class Version2000Date20171026140257 extends SimpleMigrationStep {
 
 			$update->setParameter('token', $token)
 				->setParameter('room_id', (int) $row['id'], IQueryBuilder::PARAM_INT)
-				->execute();
+				->executeStatement();
 		}
 		$output->finishProgress();
-
 	}
 
 	/**
