@@ -48,6 +48,9 @@ class Participant {
 	public const NOTIFY_MENTION = 2;
 	public const NOTIFY_NEVER = 3;
 
+	public const NOTIFY_CALLS_OFF = 0;
+	public const NOTIFY_CALLS_ON = 1;
+
 	public const PRIVACY_PUBLIC = 0;
 	public const PRIVACY_PRIVATE = 1;
 
@@ -95,6 +98,10 @@ class Participant {
 	public function canStartCall(IConfig $config): bool {
 		$defaultStartCall = (int) $config->getAppValue('spreed', 'start_calls', Room::START_CALL_EVERYONE);
 
+		if (!($this->getPermissions() & Attendee::PERMISSIONS_CALL_START)) {
+			return false;
+		}
+
 		if ($defaultStartCall === Room::START_CALL_EVERYONE) {
 			return true;
 		}
@@ -109,4 +116,34 @@ class Participant {
 
 		return false;
 	}
+
+	public function getPermissions(): int {
+		$permissions = $this->getPermissionsFromFallbackChain();
+
+		if ($this->hasModeratorPermissions()) {
+			// Moderators can always do everything
+			$permissions = Attendee::PERMISSIONS_MAX_DEFAULT;
+		}
+
+		return $permissions;
+	}
+
+	protected function getPermissionsFromFallbackChain(): int {
+		if ($this->getAttendee()->getPermissions() !== Attendee::PERMISSIONS_DEFAULT) {
+			return $this->getAttendee()->getPermissions();
+		}
+
+		if ($this->room->getCallPermissions() !== Attendee::PERMISSIONS_DEFAULT) {
+			// The currently ongoing call is in a special mode
+			return $this->room->getCallPermissions();
+		}
+
+		if ($this->room->getDefaultPermissions() !== Attendee::PERMISSIONS_DEFAULT) {
+			// The conversation has some permissions set
+			return $this->room->getDefaultPermissions();
+		}
+
+		// Falling back to an unrestricted set of permissions, only ignoring the lobby is off
+		return Attendee::PERMISSIONS_MAX_DEFAULT & ~Attendee::PERMISSIONS_LOBBY_IGNORE;
+	}
 }
