@@ -133,7 +133,7 @@ class TalkSession {
 		$this->session->set($key, json_encode($values));
 	}
 
-	public function renewSessionId() {
-		$this->session->regenerateId();
+	public function renewSessionId(): void {
+		$this->session->regenerateId(true, true);
 	}
 }
